pub struct ContainerMetadata {
pub version: Option<u16>,
pub ingest_settings: Option<IngestSettings>,
}Expand description
Metadata supplied with an item container containing logs.
See also: https://develop.sentry.dev/sdk/telemetry/logs/#version-and-ingest_settings-properties.
Versions
Behaviour
Different versions influence how logs are normalized and processed:
| Version | client ip | user agent |
|---|---|---|
| none | {{auto}} | always |
| 2 | {{auto}}, settings | settings |
For example, in version 2:
- the client ip is inferred if either the client address attribute is
set to
{{auto}}or the ingest settings specifyinfer_ipasauto. - the user agent is only inferred if ingest settings specify
infer_user_agentasauto, while for older SDKs which do not send any ingest settings, the user agent is always automatically inferred.
Schema Changelog
| Version | Changes |
|---|---|
| 2 | Adds ingest_settings |
Fields
version: Option<u16>The metadata version
The version influences how logs are processed during ingestion.
Currently supported versions:
none: no processing changes2: adds support foringest_settings
ingest_settings: Option<IngestSettings>Settings controlling parts of the ingestion of individual logs.
Supported since version 2.